UdsClient

Struct UdsClient 

pub struct UdsClient<'a, T: CanSocketTx> { /* private fields */ }

Implementations

Source

impl<'a, T: CanSocketTx> UdsClient<'a, T>

pub fn new(channel: T, id: u32, resp: &'a LazyLock<Arc<ResponseSlot>>) -> Self

Create a new UdsClient instance.

Takes a CAN socket channel channel, a 32-bit identifier id, and a reference to a ResponseSlot wrapped in Arc. The Id::Extended is used to create a unique identifier for the CAN frame.

pub async fn send_command<P: Into<u8>, M: Into<u8>>( &mut self, pci: P, cmd: M, args: &[u8], ) -> Result<(), DiagError>

Send a command without expecting a response.

This function sends a command using ISO 15765-2 format, which includes PCI, CMD, and ARGS. The args are added to the frame and sent using the send_raw method.

pub async fn send_frame(&mut self, frame: UdsFrame) -> Result<(), DiagError>

Send an UDS frame without expecting a response.

This function sends the given UdsFrame to the CAN bus using the send_raw method after converting the frame into a byte vector.

pub async fn send_frame_with_response( &mut self, frame: UdsFrame, ) -> Result<UdsFrame, DiagError>

Send an UDS frame and wait for a response.

This function sends an UdsFrame to the CAN bus and waits for a response. If the response is valid (Response::Ok), it returns the response frame, otherwise returns the error contained in Response::Error.

pub async fn send_command_with_response<P: Into<u8>, M: Into<u8>>( &mut self, pci: P, cmd: M, args: &[u8], ) -> Result<UdsFrame, DiagError>

Send a command with the response.

This function is similar to send_command but expects a response after sending the command. It returns the response frame (UdsFrame) if successful, or the error if something went wrong.

pub async fn receive(&mut self) -> Response

Receive a frame from the UDS server.

This function waits for and receives a response from the UDS server using the ResponseSlot. It blocks until a response is available and returns the response.

Source

impl<T: CanSocketTx> UdsClient<'_, T>

pub async fn uds_reset_ecu(&mut self) -> Result<(), DiagError>

Service ID: 0x11 - ECU Reset Description: The function will request an ECU reset event.

Source

impl<T: CanSocketTx> UdsClient<'_, T>

pub async fn uds_real_time_data_slow(&mut self) -> Result<(), DiagError>

Service ID: 0x2A - Data Transmission Sub-ID: 0x01 Description: The function will request an Realtime data sent from ECU with slow rate.

pub async fn uds_real_time_data_medium(&mut self) -> Result<(), DiagError>

Service ID: 0x2A - Data Transmission Sub-ID: 0x02 Description: The function will request an Realtime data sent from ECU with medium rate.

pub async fn uds_real_time_data_fast(&mut self) -> Result<(), DiagError>

Service ID: 0x2A - Data Transmission Sub-ID: 0x03 Description: The function will request an Realtime data sent from ECU with fast rate.

pub async fn uds_real_time_data_stop(&mut self) -> Result<(), DiagError>

Service ID: 0x2A - Data Transmission Sub-ID: 0x04 Description: The function will send a stop event for realtime data from ECU.