Struct UdsClient

pub struct UdsClient<'a, T: CanSocketTx> { /* private fields */ }

Implementations

Source

impl<'a, T: CanSocketTx> UdsClient<'a, T>

pub fn new(channel: T, id: u32, resp: &'a LazyLock<Arc<ResponseSlot>>) -> Self

pub fn send_command<P: Into<u8>, M: Into<u8>>( &mut self, pci: P, cmd: M, args: &[u8], ) -> Result<(), DiagError>

Send a command without the response. The frame includes as ISO 15765-2

pub async fn send_command_with_response<P: Into<u8>, M: Into<u8>>( &mut self, pci: P, cmd: M, args: &[u8], ) -> Result<UdsResponse, DiagError>

Send a command with the response. The frame includes as ISO 15765-2

pub async fn receive(&mut self) -> Response

Receive the frame from UDS server

Source

impl<T: CanSocketTx> UdsClient<'_, T>

pub async fn uds_reset_118(&mut self) -> Result<(), DiagError>

Service ID: 0x11 - ECU Reset Sub-ID: 0x40 Description: The function will request an ECU reset event for Realtime chip.

pub async fn uds_reset_148(&mut self) -> Result<(), DiagError>

Service ID: 0x11 - ECU Reset Sub-ID: 0x41 Description: The function will request an ECU reset event for Telematic chip.

pub async fn uds_reset_imx(&mut self) -> Result<(), DiagError>

Service ID: 0x11 - ECU Reset Sub-ID: 0x42 Description: The function will request an ECU reset event for IMX chip.

pub async fn uds_reset_esp32_wifi(&mut self) -> Result<(), DiagError>

Service ID: 0x11 - ECU Reset Sub-ID: 0x43 Description: The function will request an ECU reset event for Esp-Wifi chip.

pub async fn uds_reset_esp32_ble(&mut self) -> Result<(), DiagError>

Service ID: 0x11 - ECU Reset Sub-ID: 0x44 Description: The function will request an ECU reset event for Esp-Ble chip.

pub async fn uds_reset_lte(&mut self) -> Result<(), DiagError>

Service ID: 0x11 - ECU Reset Sub-ID: 0x45 Description: The function will request an ECU reset event for LTE chip.

pub async fn uds_reset_lizard(&mut self) -> Result<(), DiagError>

Service ID: 0x11 - ECU Reset Sub-ID: 0x46 Description: The function will request an ECU reset event for Lizard chip.

pub async fn uds_reset_cendric(&mut self) -> Result<(), DiagError>

Service ID: 0x11 - ECU Reset Sub-ID: 0x47 Description: The function will request an ECU reset event for Cendric chip.

Source

impl<T: CanSocketTx> UdsClient<'_, T>

pub async fn get_ecu_log(&mut self, _file: File) -> Result<(), DiagError>

Service ID: 0x36 - Transfer Data Description: The function will request a data transfer from ECU. The data will store in the as raw binary

Source

impl<T: CanSocketTx> UdsClient<'_, T>

pub async fn uds_real_time_data_slow(&mut self) -> Result<(), DiagError>

Service ID: 0x2A - Data Transmission Sub-ID: 0x01 Description: The function will request an Realtime data sent from ECU with slow rate.

pub async fn uds_real_time_data_medium(&mut self) -> Result<(), DiagError>

Service ID: 0x2A - Data Transmission Sub-ID: 0x02 Description: The function will request an Realtime data sent from ECU with medium rate.

pub async fn uds_real_time_data_fast(&mut self) -> Result<(), DiagError>

Service ID: 0x2A - Data Transmission Sub-ID: 0x03 Description: The function will request an Realtime data sent from ECU with fast rate.

pub async fn uds_real_time_data_stop(&mut self) -> Result<(), DiagError>

Service ID: 0x2A - Data Transmission Sub-ID: 0x04 Description: The function will send a stop event for realtime data from ECU.